<?php

/**
 * Category Block Six section
 *
 * This is the template for the content of Category Block Six section.
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */

if ( ! function_exists( 'daily_insight_pro_add_category_block_six' ) ) :
    /**
     * Add Category Block Six section
     *
     * @since Daily Insight Pro 1.0
     */
    function daily_insight_pro_add_category_block_six() { 

        // Check if Category Block Six is enabled on frontpage
        $options = daily_insight_pro_get_theme_options(); 

        $category_block_six_enable = (bool)( $options['enable_category_block_six'] );
        if ( true !== $category_block_six_enable ) {
            return false;
        }
        // Get Category Block Six section details
        $section_details = array();
        $section_details = apply_filters( 'daily_insight_pro_filter_category_block_six_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render Category Block Six section .
        daily_insight_pro_render_category_block_six_section( $section_details );
    }
endif;
add_action( 'daily_insight_pro_front_page_container_action', 'daily_insight_pro_add_category_block_six', 60 );


if ( ! function_exists( 'daily_insight_pro_get_category_block_six_section_details' ) ) :
    /**
     * Category Block Six section details.
     *
     * @since Daily Insight Pro 1.0
     *
     * @param array $input Category Block Six section details.
     */
    function daily_insight_pro_get_category_block_six_section_details( $input ) {
        $options = daily_insight_pro_get_theme_options(); 

        // Category Block Six type
        $category_block_six_content_type    = $options['category_block_six_type'];
        $no_of_posts = 4;
        $content = array();

        switch ( $category_block_six_content_type ) {

            case 'demo':
                $no_of_posts = 4; // Initialize and overwrite no of posts in demo by 3
                $images = array( 'blog-01.jpg', 'blog-02.jpg', 'blog-03.jpg','blog-04.jpg' ); // An array of demo images

                for ( $index = 0; $index < $no_of_posts ; $index++ ) {
                    $content[$index]['img_array'] = array( get_template_directory_uri(). '/assets/uploads/'. $images[$index] );
                    $content[$index]['url']       = '#';
                    $content[$index]['date']      = 'July 25, 2016';
                    $content[$index]['date_link'] = '#';
                    $content[$index]['title']     = esc_html__( 'Proin gravida nibh vel velit  auctor aliquet. Aenean sollicit.','daily-insight-pro' );
                    $content[$index]['terms']     = array( esc_html__( 'Lifestyle','daily-insight-pro' ),esc_html__( 'Travel','daily-insight-pro' ),esc_html__( 'Photo','daily-insight-pro' ) );
                    $content[$index]['excerpt']   = esc_html__( 'Proin gravida nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit. Duis sed odio sit amet nibh vulputate cursus a sit amet mauris.','daily-insight-pro' );
                }
            break;

            case 'category':
              
                $categories = array();
                $categories = !empty( $options['category_block_six_category_type'] ) ? $options['category_block_six_category_type'] : array();
                $category = array_filter( $categories );

                if ( ! empty( $category ) ) {

                    $args = array(
                        'category__in'        => $category,
                        'posts_per_page'      => $no_of_posts,
                    );
                }

                if( !empty( $args ) ) :

                    $custom_posts = get_posts( $args );

                    $index = 0;
                    foreach ( $custom_posts as $key => $custom_post ) {

                        if ( has_post_thumbnail( $custom_post->ID ) ) {

                            if( $index == 0 ){
                                $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $custom_post->ID ), 'daily-insight-pro-travel-long' );

                            } else {
                                $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $custom_post->ID ), 'daily-insight-pro-category' );
                            }
                            $content[$index]['img_array'] = $img_array;
                        } 
                        $year  = get_the_time('Y', $custom_post->ID );
                        $month = get_the_time('m', $custom_post->ID );
                        $day   = get_the_time('d', $custom_post->ID );

                        $content[$index]['date_link'] = get_day_link( $year, $month, $day );
                        $content[$index]['title']     = get_the_title( $custom_post->ID );
                        $content[$index]['url']       = get_the_permalink( $custom_post->ID );
                        $content[$index]['terms']     = get_the_category( $custom_post->ID );
                        $content[$index]['date']      = get_the_date( '', $custom_post );
                        $content[$index]['excerpt']   = daily_insight_pro_trim_content( 35, $custom_post );
                        $index++;
                    }
                endif;
            break;

            default:
            break;
                
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
    return $input; 
    }
endif;
// Category Block Six section content details.
add_filter( 'daily_insight_pro_filter_category_block_six_section_details', 'daily_insight_pro_get_category_block_six_section_details' );

if ( ! function_exists( 'daily_insight_pro_render_category_block_six_section' ) ) :
    /**
     * Start section Category Block Six
     *
     * @return string Category Block Six content
     * @since Daily Insight Pro 1.0
     *      
     */
    function daily_insight_pro_render_category_block_six_section( $content_details = array() ) {

        $options = daily_insight_pro_get_theme_options();
        $section_title = $options['category_block_six_title'];
        $content_type = $options['category_block_six_type'];
        $index = 0;

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <section id="latest-blog" class="page-section">
            <?php 
            $section_title = ( $options['category_block_six_type'] == 'demo' ) ? esc_html__( 'Latest Blog','daily-insight-pro' ) : $section_title;
            if( !empty( $section_title ) ) : ?>
            <header class="entry-header">
                <h2 class="entry-title category-title"><?php echo esc_html( $section_title ); ?></h2> 
            </header>
            <?php endif; 

            foreach( $content_details as $content ) : 
                if( $index == 0 ) { ?>
                <div class="type-post has-post-thumbnail hentry bg-white clear">
                <?php } else { 
                    if( empty( $content['img_array'][0] ) ) { $class = 'no-post-thumbnail'; }
                    else { $class = 'has-post-thumbnail';} ?>

                <div class="type-post <?php echo $class; ?> hentry image-alignment image-align-left bg-white clear">
                <?php } 
                    if( !empty( $content['img_array'][0] ) ) : ?>
                    <div class="image-wrapper">
                        <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                        <div class="overlay"></div></a>
                    </div><!-- .image-wrapper -->
                    <?php endif; ?>
                    
                    <div class="entry-content">

                        <div class="entry-meta">
                            <span class="posted-on"><a href="<?php echo esc_url( $content['date_link'] ); ?>"><time><?php echo esc_html( $content['date'] ); ?></time></a></span>
                            <span class="tag">
                                <?php $post_categories = $content['terms'];
                                if( !empty ( $post_categories ) ) :
                                    if( 'demo' == $content_type ) { 
                                        foreach ( $post_categories as $post_category ) { ?>
                                            <a class="category" href="#"><?php echo esc_html( $post_category ); ?></a>                    
                                    <?php } } 
                                    else { 
                                        foreach ( $post_categories as $post_category ) {
                                            $category_id   = $post_category->term_id;
                                            $category_name = $post_category->name;
                                            $category_url  = get_category_link( $category_id );
                                        ?>
                                        <a class="category" href="<?php echo esc_url( $category_url ); ?>"><?php echo esc_html( $category_name ); ?></a>
                                    <?php } }
                                endif; ?>
                            </span>
                        </div><!-- .entry-meta -->
                        <div class="post-title">
                            <h5><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h5>
                        </div><!-- .post-title -->
                        <?php if( !empty( $content['excerpt'] ) ) : ?>
                        <div class="post-desc">
                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                        </div>
                        <?php endif; ?>
                        <?php 
                        $readmore_text = ( $options['category_block_six_type'] == 'demo' ) ? esc_html__( 'Read More','daily-insight-pro' ) : $options['readmore_text'];
                        if( !empty( $readmore_text ) ) : ?>
                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="view-more"><?php echo esc_html( $readmore_text ); ?></a>
                        <?php endif; ?>
                    </div><!-- end .entry-container -->
                </div>
            <?php $index++; endforeach; ?>
        </section><!-- #latest-blog -->
    <?php }
endif;